Struct wavefront_obj::mtl::Material [−][src]
pub struct Material {Show 17 fields
pub name: String,
pub specular_coefficient: f64,
pub color_ambient: Color,
pub color_diffuse: Color,
pub color_specular: Color,
pub color_emissive: Option<Color>,
pub optical_density: Option<f64>,
pub alpha: f64,
pub illumination: Illumination,
pub ambient_map: Option<String>,
pub diffuse_map: Option<String>,
pub specular_map: Option<String>,
pub specular_exponent_map: Option<String>,
pub dissolve_map: Option<String>,
pub displacement_map: Option<String>,
pub decal_map: Option<String>,
pub bump_map: Option<String>,
}Expand description
A single material that can be applied to any face. They are generally applied by using the Phong shading model.
Fields
name: Stringspecular_coefficient: f64color_ambient: Colorcolor_diffuse: Colorcolor_specular: Colorcolor_emissive: Option<Color>optical_density: Option<f64>alpha: f64illumination: Illuminationambient_map: Option<String>diffuse_map: Option<String>specular_map: Option<String>specular_exponent_map: Option<String>dissolve_map: Option<String>displacement_map: Option<String>decal_map: Option<String>bump_map: Option<String>Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more