Type Definition wavefront_obj::obj::VertexIndex [−][src]
pub type VertexIndex = usize;Expand description
An index into the vertices array of an object, representing a vertex in
the mesh. After parsing, this is guaranteed to be a valid index into the
array, so unchecked indexing may be used.